@@ -40,8 +40,5 @@ fn parse_body_only() {
     let parsed = conventional_commit_parser::parse_body(&body);
 
     // Assert
-    assert_that(&parsed)
-        .is_ok()
-        .is_some()
-        .is_equal_to(body.as_str());
+    assert_that(&parsed).is_ok().is_some().is_equal_to(body);
 }
