@@ -7,7 +7,7 @@
 //     If ! is used, BREAKING CHANGE: MAY be omitted from the footer section, and the commit description
 //     SHALL be used to describe the breaking change.
 // 14. Types other than feat and fix MAY be used in your commit messages, e.g., docs: updated ref docs.
-use conventional_commit_parser::commit::{CommitType, Footer};
+use conventional_commit_parser::commit::{CommitType, Footer, Separator};
 use conventional_commit_parser::parse;
 use indoc::indoc;
 
@@ -223,8 +223,9 @@ fn commits_with_footer() {
     assert_contains_footer(
         parsed,
         Footer {
-            token: "a-token",
-            content: "this is a token",
+            token: "a-token".to_string(),
+            content: "this is a token".to_string(),
+            ..Default::default()
         },
     );
 }
@@ -248,15 +249,17 @@ fn commits_with_footers() {
     assert_contains_footer(
         parsed,
         Footer {
-            token: "a-token",
-            content: "this is a token",
+            token: "a-token".to_string(),
+            content: "this is a token".to_string(),
+            ..Default::default()
         },
     );
     assert_contains_footer(
         parsed,
         Footer {
-            token: "another-token",
-            content: "this is a token with hash separator",
+            token: "another-token".to_string(),
+            content: "this is a token with hash separator".to_string(),
+            token_separator: Separator::Hash,
         },
     );
 }
@@ -302,8 +305,9 @@ fn footer_with_breaking_change_ok() {
     assert_contains_footer(
         &parsed,
         Footer {
-            token: "BREAKING CHANGE",
-            content: "message",
+            token: "BREAKING CHANGE".to_string(),
+            content: "message".to_string(),
+            ..Default::default()
         },
     );
 
@@ -325,8 +329,9 @@ fn footer_with_no_body() {
     assert_contains_footer(
         &parsed,
         Footer {
-            token: "BREAKING CHANGE",
-            content: "message",
+            token: "BREAKING CHANGE".to_string(),
+            content: "message".to_string(),
+            ..Default::default()
         },
     );
 
@@ -352,19 +357,22 @@ fn footer_with_new_line() {
     assert_contains_footer(
         &parsed,
         Footer {
-            token: "BREAKING CHANGE",
+            token: "BREAKING CHANGE".to_string(),
             content: indoc!(
                 "a long message that describe a footer
     with multiple new line"
-            ),
+            )
+            .to_string(),
+            ..Default::default()
         },
     );
 
     assert_contains_footer(
         &parsed,
         Footer {
-            token: "another-footer",
-            content: "with content",
+            token: "another-footer".to_string(),
+            content: "with content".to_string(),
+            ..Default::default()
         },
     );
 
